public abstract interface Trait /* Trait*/ {
  @org.jetbrains.annotations.NotNull()
  @org.jetbrains.annotations.Nullable()
  public abstract java.lang.String notNullWithN();//  notNullWithN()

  @org.jetbrains.annotations.NotNull()
  @org.jetbrains.annotations.Nullable()
  public abstract java.lang.String nullableWithNN();//  nullableWithNN()

  @org.jetbrains.annotations.NotNull()
  public abstract java.lang.String getNotNullVal();//  getNotNullVal()

  @org.jetbrains.annotations.NotNull()
  public abstract java.lang.String getNotNullVar();//  getNotNullVar()

  @org.jetbrains.annotations.NotNull()
  public abstract java.lang.String notNull(@org.jetbrains.annotations.NotNull() java.lang.String);//  notNull(java.lang.String)

  @org.jetbrains.annotations.NotNull()
  public abstract java.lang.String notNullWithNN();//  notNullWithNN()

  @org.jetbrains.annotations.Nullable()
  public abstract java.lang.String getNullableVal();//  getNullableVal()

  @org.jetbrains.annotations.Nullable()
  public abstract java.lang.String getNullableVar();//  getNullableVar()

  @org.jetbrains.annotations.Nullable()
  public abstract java.lang.String nullable(@org.jetbrains.annotations.Nullable() java.lang.String);//  nullable(java.lang.String)

  @org.jetbrains.annotations.Nullable()
  public abstract java.lang.String nullableWithN();//  nullableWithN()

  public abstract void setNotNullVar(@org.jetbrains.annotations.NotNull() java.lang.String);//  setNotNullVar(java.lang.String)

  public abstract void setNullableVar(@org.jetbrains.annotations.Nullable() java.lang.String);//  setNullableVar(java.lang.String)
}
