public final class FileFacadeKt /* FileFacadeKt*/ {
  @org.jetbrains.annotations.NotNull()
  private static @org.jetbrains.annotations.NotNull() java.lang.String notNullVar;

  @org.jetbrains.annotations.NotNull()
  private static final @org.jetbrains.annotations.NotNull() java.lang.String notNullVal;

  @org.jetbrains.annotations.NotNull()
  private static final @org.jetbrains.annotations.NotNull() java.lang.String privateNn;

  @org.jetbrains.annotations.Nullable()
  private static @org.jetbrains.annotations.Nullable() java.lang.String nullableVar;

  @org.jetbrains.annotations.Nullable()
  private static final @org.jetbrains.annotations.Nullable() java.lang.String nullableVal;

  @org.jetbrains.annotations.Nullable()
  private static final @org.jetbrains.annotations.Nullable() java.lang.String privateN;

  @<error>()
  @org.jetbrains.annotations.NotNull()
  public static final @org.jetbrains.annotations.NotNull() java.lang.String getNotNullValWithGet();//  getNotNullValWithGet()

  @<error>()
  @org.jetbrains.annotations.NotNull()
  public static final @org.jetbrains.annotations.NotNull() java.lang.String getNotNullVarWithGetSet();//  getNotNullVarWithGetSet()

  @<error>()
  @org.jetbrains.annotations.NotNull()
  public static final @org.jetbrains.annotations.NotNull() java.lang.String notNullWithN();//  notNullWithN()

  @<error>()
  @org.jetbrains.annotations.NotNull()
  public static final @org.jetbrains.annotations.NotNull() java.lang.String notNullWithNN();//  notNullWithNN()

  @<error>()
  @org.jetbrains.annotations.Nullable()
  public static final @org.jetbrains.annotations.Nullable() java.lang.String getNullableValWithGet();//  getNullableValWithGet()

  @<error>()
  @org.jetbrains.annotations.Nullable()
  public static final @org.jetbrains.annotations.Nullable() java.lang.String getNullableVarWithGetSet();//  getNullableVarWithGetSet()

  @<error>()
  @org.jetbrains.annotations.Nullable()
  public static final @org.jetbrains.annotations.Nullable() java.lang.String nullableWithN();//  nullableWithN()

  @<error>()
  @org.jetbrains.annotations.Nullable()
  public static final @org.jetbrains.annotations.Nullable() java.lang.String nullableWithNN();//  nullableWithNN()

  @<error>()
  public static final void setNotNullVarWithGetSet(@org.jetbrains.annotations.NotNull() @org.jetbrains.annotations.NotNull() java.lang.String);//  setNotNullVarWithGetSet(@org.jetbrains.annotations.NotNull() java.lang.String)

  @<error>()
  public static final void setNullableVarWithGetSet(@org.jetbrains.annotations.Nullable() @org.jetbrains.annotations.Nullable() java.lang.String);//  setNullableVarWithGetSet(@org.jetbrains.annotations.Nullable() java.lang.String)

  @org.jetbrains.annotations.NotNull()
  public static final @org.jetbrains.annotations.NotNull() java.lang.String getNotNullVal();//  getNotNullVal()

  @org.jetbrains.annotations.NotNull()
  public static final @org.jetbrains.annotations.NotNull() java.lang.String getNotNullVar();//  getNotNullVar()

  @org.jetbrains.annotations.NotNull()
  public static final @org.jetbrains.annotations.NotNull() java.lang.String notNull(@org.jetbrains.annotations.NotNull() @org.jetbrains.annotations.NotNull() java.lang.String);//  notNull(@org.jetbrains.annotations.NotNull() java.lang.String)

  @org.jetbrains.annotations.Nullable()
  public static final @org.jetbrains.annotations.Nullable() java.lang.String getNullableVal();//  getNullableVal()

  @org.jetbrains.annotations.Nullable()
  public static final @org.jetbrains.annotations.Nullable() java.lang.String getNullableVar();//  getNullableVar()

  @org.jetbrains.annotations.Nullable()
  public static final @org.jetbrains.annotations.Nullable() java.lang.String nullable(@org.jetbrains.annotations.Nullable() @org.jetbrains.annotations.Nullable() java.lang.String);//  nullable(@org.jetbrains.annotations.Nullable() java.lang.String)

  private static final @org.jetbrains.annotations.Nullable() java.lang.String privateFun(@org.jetbrains.annotations.NotNull() java.lang.String, @org.jetbrains.annotations.Nullable() java.lang.String);//  privateFun(@org.jetbrains.annotations.NotNull() java.lang.String, @org.jetbrains.annotations.Nullable() java.lang.String)

  public static final void setNotNullVar(@org.jetbrains.annotations.NotNull() @org.jetbrains.annotations.NotNull() java.lang.String);//  setNotNullVar(@org.jetbrains.annotations.NotNull() java.lang.String)

  public static final void setNullableVar(@org.jetbrains.annotations.Nullable() @org.jetbrains.annotations.Nullable() java.lang.String);//  setNullableVar(@org.jetbrains.annotations.Nullable() java.lang.String)
}
